/*
 * String to embed in binaries to identify package
 */

char pkg[]="$NetKit: netkit-telnet-0.16 $";
